import {
  Message
} from 'element-ui';
import {
  dataapiDetail,
  openurl
} from './report';
import {
  optionList,
  enumCheck
} from '@/api/newbi/bigdata';
import {
  dictDetail
} from '@/api/newbi/dict';
import {
  param
} from "./config";
// 整理树结构
export const countTreeOptions = (originData) => {
  originData.forEach((i) => {
    i.children = [];
    i.KEY = i.KEY || i.VALUE;
  });
  let parents = [...originData];
  let res = [],
    childrens = [];
  originData.forEach((i) => {
    if (i.PID == "0") {
      res.push(i);
    } else {
      childrens.push(i);
    }
  });
  childrens.forEach((i) => {
    let parent = parents.find((j) => j.ID == i.PID);
    if (parent) {
      parent.children.push(i);
    }
  });
  return res;
};
// 去掉子项空数组
export const clearChildren = node => {
  if (!node.children) return;
  if (!node.children.length) {
    delete node.children;
  } else {
    node.children.forEach(clearChildren);
  }
};
//被修改的下拉 apiID 全局变量list 表单list
export const getAPIData = (filter,enumId,formAllVar,componentList,type,value = {}) => new Promise((resolve, reject) =>{
  dataapiDetail(enumId).then(res => {
    let {apiKey} = res.data.data;
     let formVarObj = {}
    //获取表单内关联的变量
    if (formAllVar && formAllVar.length && componentList && componentList.length){
      formAllVar.forEach((i,k)=>{
        if (i.varType && i.varType.length){
          //默认值
          if (i.varType[0] === 1){
            formVarObj[i.key] = i.def
          }
          //系统全局变量
          if (i.varType[0] === 2){
            formVarObj[i.key] = i.varType[1]
          }
          //表单内全局变量
          if (i.varType[0] === 3){
            let varObbj = componentList.find(o=>o.__vModel__ && o.__vModel__ === i.varType[1])
            if (type === 'search'){
              formVarObj[i.key] = varObbj.value
            }else {
              formVarObj[i.key] = varObbj.__config__.defaultValue
            }
          }
        }
      })
    }
    openurl(apiKey, {...param, ...value,...formVarObj}).then((res) => {
      let data = res.data.data;
      let hasChild = data.find(i => i.PID)
      if (hasChild) {
        let tree = countTreeOptions(data);
        tree.forEach(clearChildren);
        filter.options = tree;
      } else {
        filter.options = data.map(i => ({
          id: i.ID || i.KEY || i.key || i.VALUE || i.value,
          fullName: i.VALUE || i.value
        }));
      }
      resolve();
    }).catch(res => {
        filter.options = []
        resolve();
   });
  })
});
// 获取枚举可选值
export const getEnumData = (filter, cubeDataId, visualId, componentId, isEdit) => {
  let {
    enumSource,
    enumId
  } = filter;
  if (enumSource == "1") {
    filter.loading = true;
    let {
      tableName,
      columnName
    } = filter;
    if (!tableName || !columnName) {
      tableName = filter.column.tableName;
      columnName = filter.column.columnName;
    }
    if (isEdit) {
      enumCheck({
        tableName,
        columnName,
        cubeDataId
      }).then(() => {
        optionList({
          tableName,
          columnName,
          cubeDataId,
          visualId,
          componentId
        }).then((res) => {
          filter.options = res.data.data.map((i) => ({
            KEY: i[columnName],
            VALUE: i[columnName],
          }));
          filter.loading = false;
        });
      }).catch(() => {
        Message.warning('此数据集不支持原始数据聚合');
        filter.loading = false;
      });
    } else {
      optionList({
        tableName,
        columnName,
        cubeDataId,
        visualId,
        componentId
      }).then((res) => {
        filter.options = res.data.data.map((i) => ({
          KEY: i[columnName],
          VALUE: i[columnName],
        }));
        filter.loading = false;
      });
    }
  } else if (enumSource == "2") {
    if (!enumId) {
      return Message.warning('请选择api');
    }
    filter.loading = true;
    dataapiDetail(enumId).then((res) => {
      let {
        apiKey
      } = res.data.data;
      openurl(apiKey, param).then((res) => {
        filter.loading = false;
        let data = res.data.data;
        if (!data.length) {
          filter.options = data;
        }
        if (data[0].ID) {
          let tree = countTreeOptions(data);
          tree.forEach(clearChildren);
          filter.options = tree;
        } else {
          filter.options = data.map(i => ({
            KEY: i.KEY || i.VALUE,
            VALUE: i.VALUE
          }));
        }
      });
    });
  } else {
    if (!enumId) {
      return Message.warning('请选择字典');
    }
    dictDetail({
      id: enumId
    }).then((res) => {
      let content = JSON.parse(res.data.data.content || '[]');
      filter.options = content.map(i => ({
        KEY: i.key,
        VALUE: i.value
      }));
    });
  }
};
export const onEnumSelectAll = filter => {
  let options = filter.options;
  let arr = [];
  options.forEach((i) => getOptionValue(arr, i));
  filter.conditions[0].values = arr;
};
export const getOptionValue = (arr, item) => {
  if (item.children) {
    item.children.forEach((i) => {
      getOptionValue(arr, i);
    });
  } else {
    arr.push(item.KEY);
  }
};
